@@ -1,6 +1,6 @@
 package HTTP::Headers::UserAgent;
 # ABSTRACT: identify browser by parsing User-Agent string (deprecated)
-$HTTP::Headers::UserAgent::VERSION = '3.08';
+$HTTP::Headers::UserAgent::VERSION = '3.09';
 use 5.006;
 use strict;
 use warnings;
@@ -260,6 +260,10 @@ a given agent is a robot/crawler though.
 
 =back
 
+=head1 REPOSITORY
+
+L<https://github.com/neilb/HTTP-Headers-UserAgent>
+
 =head1 AUTHOR
 
 This module is now maintained by Neil Bowers <neilb@cpan.org>.
